@@ -1,3 +1,5 @@
+import importlib
+
 import pytest
 
 import cssutils
@@ -9,6 +11,12 @@ collect_ignore = [
 ]
 
 
+try:
+    importlib.import_module('lxml')
+except ImportError:
+    collect_ignore += ['examples/style.py']
+
+
 @pytest.fixture(autouse=True)
 def hermetic_profiles():
     """
